﻿using System.Collections.Generic;
using System.Windows;
using Syncfusion.UI.Xaml.Grid.Converter;
using Syncfusion.XlsIO;

namespace ExcelExportTestUtility {
    public partial class MainWindow {
        public MainWindow() {
            InitializeComponent();
            var person = new Person {
                Name = "John Doe",
                PrimaryLanguage = "English",
                SecondaryLanguage = "Spanish",
                TertiaryLanguage = "French"
            };

            DataGrid.ItemsSource = new List<Person> { person };
        }

        private void ExportClick(object sender, RoutedEventArgs e) {
            var grid = DataGrid;

            var options = new ExcelExportingOptions {
                ExportStackedHeaders = true
            };

            options.ExcludeColumns.Add("PrimaryLanguage");
            options.ExcludeColumns.Add("SecondaryLanguage");
            options.ExcludeColumns.Add("TertiaryLanguage");

            using (var excelEngine = grid.ExportToExcel(grid.View, options)) {
                var workBook = excelEngine.Excel.ActiveWorkbook;
                var fileName = SaveWorkbook(workBook);

                System.Diagnostics.Process.Start(fileName);
            };
        }

        public string SaveWorkbook(IWorkbook workbook) {
            const string fileName = "Export";
            const string extension = ".xlsx";
            try {
                const string fullFileName = fileName + extension;
                workbook.SaveAs(fullFileName);
                return fullFileName;
            } catch {
                var postfix = 1;
                while (true) {
                    try {
                        var fullFileName = fileName + '-' + postfix + extension;
                        workbook.SaveAs(fullFileName);
                        return fullFileName;
                    } catch {
                        postfix++;
                    }
                }
            }
        }
    }

    public class Person {
        public string Name { get; set; }
        public string PrimaryLanguage { get; set; }
        public string SecondaryLanguage { get; set; }
        public string TertiaryLanguage { get; set; }
    }
}
